"""
GS1 GPC Import - A tool for importing GS1 Global Product Classification data into SQL databases.

This package provides tools for downloading, parsing, and importing GS1 GPC data
into SQL databases (SQLite and PostgreSQL), as well as exporting the data to SQL files.
"""

__version__ = '0.1.2'